@@ -71,6 +71,7 @@ class BlockTimestampGraph(object):
     def __init__(self, theta_provider):
         self._theta_provider= theta_provider
         self.block_mapper = ThetaBlockMapper()
+        self.logger = logging.getLogger('BlockTimestampGraph')
 
     def get_first_point(self):
         # Ignore the genesis block as its timestamp is 0
@@ -78,17 +79,20 @@ class BlockTimestampGraph(object):
 
     def get_last_point(self):
 #        return block_to_point(self._theta_provider.eth.getBlock('latest'))  
-        return self.get_point(6779286) #TODO: query status to get latest
+        return Point(6781175, 1596548400) #TODO: query status to get latest
 
     def get_point(self, x):
 #        return block_to_point(self._theta_provider.eth.getBlock(x))
         response = self._theta_provider.make_request(
-            json.dumps(generate_get_blocks_by_range_json_rpc(x, x, False))
+            json.dumps(generate_get_blocks_by_range_json_rpc(x, x + 1, False))
             )
         results = rpc_response_to_result(response)
         blocks = [self.block_mapper.json_dict_to_block(result) for result in results]
+        if (len(blocks) == 0) :
+            self.logger.info("failed to get block : %d\n", x)
+            return Point(x, -1)
         return block_to_point(blocks[0])
 
 
 def block_to_point(block):
-    return Point(block.height, block.timestamp)
+    return Point(int(block.height), int(block.timestamp))
